@@ -12,7 +12,10 @@ pub enum ErrorKind {
     UnableCreateEdge(usize, usize),
     VertexNotFound(usize),
     TreeContainsCycle,
-    ExistsCycle(usize)
+    GraphNotConnected,
+    ExistsCycle(usize),
+    ExistsCycleNegativeWeightInVertexId(usize),
+    ExistsCycleNegativeWeight
 }
 
 impl fmt::Display for ErrorKind {
@@ -21,7 +24,10 @@ impl fmt::Display for ErrorKind {
             ErrorKind::UnableCreateEdge(from, to) => write!(f, "It is not possible to create an edge between these vertices ({}, {})", from, to),
             ErrorKind::VertexNotFound(id) => write!(f, "Vertex ({}) not found", id),
             ErrorKind::ExistsCycle(id) => write!(f, "Found cycle in the vertex ({})", id),
+            ErrorKind::GraphNotConnected => write!(f, "Graph not connected"),
             ErrorKind::TreeContainsCycle => write!(f, "Found cycle. Tree must not contain cycle"),
+            ErrorKind::ExistsCycleNegativeWeightInVertexId(id) => write!(f, "Found cycle negative weight in the vertex ({})", id),
+            ErrorKind::ExistsCycleNegativeWeight => write!(f, "Found cycle negative weight"),
         }
     }
 }
