@@ -17,7 +17,7 @@ fn test_find_vertices_depths() {
     graph.add_edge(7, 8, 0).unwrap();
 
     let depths = algorithms::find_vertices_depths(&graph, graph.get_vertex(1).unwrap()).unwrap();
-    assert_eq!(depths.get_vertix_depth(graph.get_vertex(3).unwrap()), Some(3));
-    assert_eq!(depths.get_vertix_depth(graph.get_vertex(8).unwrap()), Some(4));
-    assert_eq!(depths.get_vertix_depth(graph.get_vertex(11).unwrap()), Some(2));
+    assert_eq!(depths.get_vertex_depth(graph.get_vertex(3).unwrap()), Some(3));
+    assert_eq!(depths.get_vertex_depth(graph.get_vertex(8).unwrap()), Some(4));
+    assert_eq!(depths.get_vertex_depth(graph.get_vertex(11).unwrap()), Some(2));
 }
\ No newline at end of file
